# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`emqx`](#emqx): A basic module for managing emqx

#### Private Classes

* `emqx::config`: Manage emqx.conf configuration file
* `emqx::install`: Manage install of emqx
* `emqx::service`: Manage emqx service

## Classes

### <a name="emqx"></a>`emqx`

Installs and configures the emqx package and service

#### Examples

##### 

```puppet
include emqx
```

#### Parameters

The following parameters are available in the `emqx` class:

* [`install_package_source`](#-emqx--install_package_source)
* [`install_version`](#-emqx--install_version)
* [`install_platform`](#-emqx--install_platform)
* [`install_package_extension`](#-emqx--install_package_extension)
* [`service_ensure`](#-emqx--service_ensure)
* [`service_enable`](#-emqx--service_enable)
* [`manage_config`](#-emqx--manage_config)
* [`config_node_name`](#-emqx--config_node_name)
* [`config_node_cookie`](#-emqx--config_node_cookie)
* [`config_node_data_dir`](#-emqx--config_node_data_dir)
* [`config_node_options`](#-emqx--config_node_options)
* [`config_cluster_name`](#-emqx--config_cluster_name)
* [`config_cluster_discovery_strategy`](#-emqx--config_cluster_discovery_strategy)
* [`config_cluster_options`](#-emqx--config_cluster_options)
* [`config_dashboard_listeners_ssl`](#-emqx--config_dashboard_listeners_ssl)
* [`config_dashboard_listeners_bind`](#-emqx--config_dashboard_listeners_bind)
* [`config_dashboard_listeners_options`](#-emqx--config_dashboard_listeners_options)
* [`config_authorization_options`](#-emqx--config_authorization_options)
* [`config_additional_configs`](#-emqx--config_additional_configs)

##### <a name="-emqx--install_package_source"></a>`install_package_source`

Data type: `String`

The location to source the package from.

Default value: `'https://www.emqx.com/en/downloads/broker'`

##### <a name="-emqx--install_version"></a>`install_version`

Data type: `String`

The version of emqx. Default: '5.0.25'

Default value: `'5.0.25'`

##### <a name="-emqx--install_platform"></a>`install_platform`

Data type: `String`

The os platform in order to download the required package.

Default value: `'el8'`

##### <a name="-emqx--install_package_extension"></a>`install_package_extension`

Data type: `String`

The file extension for the package.

Default value: `'rpm'`

##### <a name="-emqx--service_ensure"></a>`service_ensure`

Data type: `Variant[Enum['running', 'stopped'], Boolean]`

The state of the service.

Default value: `'running'`

##### <a name="-emqx--service_enable"></a>`service_enable`

Data type: `Boolean`

Boolean for enabling/disabling the service.

Default value: `true`

##### <a name="-emqx--manage_config"></a>`manage_config`

Data type: `Boolean`

Boolean for setting whether to manage emqx.conf.

Default value: `true`

##### <a name="-emqx--config_node_name"></a>`config_node_name`

Data type: `String[1]`

String for setting the name field for the node config path.

Default value: `'emqx@127.0.0.1'`

##### <a name="-emqx--config_node_cookie"></a>`config_node_cookie`

Data type: `Sensitive[String[1]]`

Sensitive string for setting the cookie field for the node config path.

Default value: `Sensitive('emqxsecretcookie')`

##### <a name="-emqx--config_node_data_dir"></a>`config_node_data_dir`

Data type: `String`

String for setting the data_dir field for the node config path.

Default value: `'/var/lib/emqx'`

##### <a name="-emqx--config_node_options"></a>`config_node_options`

Data type: `Hash`

Hash for setting additional fields under the node config path.  Note: Do not set name, cooke and data_dir fields here.

Default value: `{}`

##### <a name="-emqx--config_cluster_name"></a>`config_cluster_name`

Data type: `String[1]`

String for setting the name field for the cluster config path.

Default value: `'emqxcl'`

##### <a name="-emqx--config_cluster_discovery_strategy"></a>`config_cluster_discovery_strategy`

Data type: `Enum['manual','static','mcast','dns','etcd','k8s']`

Enum String for setting the discovery_strategy field for the cluster config path.

Default value: `'manual'`

##### <a name="-emqx--config_cluster_options"></a>`config_cluster_options`

Data type: `Hash`

Hash for setting additional fields under the cluster config path.  Note: Do not set name, cooke and data_dir fields here.
Note: Do not set name and discovery_strategy fields here.

Default value: `{}`

##### <a name="-emqx--config_dashboard_listeners_ssl"></a>`config_dashboard_listeners_ssl`

Data type: `Boolean`

Boolean for setting ssl for the dashboard listener configuration.  i.e. Use config path if true dashboard.listeners.https,
else dashboard.listeners.http.

Default value: `false`

##### <a name="-emqx--config_dashboard_listeners_bind"></a>`config_dashboard_listeners_bind`

Data type: `Variant[Integer,String[1]]`

Integer or String for setting the emqx dashboard bind address as either a port or bind ip:port respectively.

Default value: `18083`

##### <a name="-emqx--config_dashboard_listeners_options"></a>`config_dashboard_listeners_options`

Data type: `Hash`

Hash for setting additional fields under the dashboard.listeners.http or dashboard.listeners.https config path.
Note: Do not set bind and option fields here.

Default value: `{}`

##### <a name="-emqx--config_authorization_options"></a>`config_authorization_options`

Data type: `Hash`

Hash for setting additional fields under the authorization config path.

Default value:

```puppet
{
  deny_action => 'ignore',
  no_match => 'allow',
  cache => '{ enable = true }',
}
```

##### <a name="-emqx--config_additional_configs"></a>`config_additional_configs`

Data type: `Hash`

Hash for setting additional config paths and fields.
Note: Do not set the following config_paths here: node, cluster, dashboard, authorization.

Default value: `{}`

